
.. Changelog is generated automatically by PBR. Here we just point include the generated file.
   Note: this requires a bdist to have been created or the include here will fail
.. include:: ../../ChangeLog
